==> racer-0.1.1.tgz: package/lib/redisInfo.js <==
var getStarts, setStarts;
setStarts = function(client, startsLength, ver, callback) {
  return client.multi().lpush('starts', "" + (+new Date) + "." + startsLength + "," + ver).publish('$redisInfo', 'starts').exec(function(err) {
    if (err) {
      throw err;
    }
    if (callback) {
      return callback(null);
    }
  });
};
module.exports = {
  onStart: function(client, callback) {
    return client.multi().llen('starts').get('ver').exec(function(err, values) {
      var startsLength, ver;
      if (err) {
        throw err;
      }
      startsLength = values[0];
      ver = values[1] || 0;
      return setStarts(client, startsLength, ver, callback);
    });
  },
  _getStarts: getStarts = function(client, callback) {
    return client.lrange('starts', 0, -1, function(err, starts) {
      var start;
      if (err) {
        throw err;
      }
      if (starts.length === 0) {
        return client.watch('starts', function(err) {
          if (err) {
            throw err;
          }
          return client.llen('starts', function(err, value) {
            if (err) {
              throw err;
            }
            if (value > 0) {
              return client.unwatch('starts', function() {
                return getStarts(client, callback);
              });
            }
            console.error('WARNING: Redis server does not have any record of ' + 'being started by the Racer Redis loader.');
            return setStarts(client, 0, 0, function() {
              return getStarts(client, callback);
            });
          });
        });
      }
      return callback((function() {
        var _i, _len, _results;
        _results = [];
        for (_i = 0, _len = starts.length; _i < _len; _i++) {
          start = starts[_i];
          _results.push(start.split(','));
        }
        return _results;
      })());
    });
  },
  subscribeToStarts: function(subClient, client, callback) {
    if (!subClient.__startsListener) {
      subClient.__startsListener = true;
      subClient.on('message', function(channel, message) {
        if (!(channel === '$redisInfo' && message === 'starts')) {
          return;
        }
        return getStarts(client, callback);
      });
    }
    subClient.subscribe('$redisInfo');
    return getStarts(client, callback);
  },
  _console: console
};

==> racer-0.1.3.tgz: package/lib/redisInfo.js <==
var getStarts, setStarts;

setStarts = function(client, startsLength, ver, callback) {
  return client.multi().lpush('starts', "" + (+(new Date)) + "." + startsLength + "," + ver).publish('$redisInfo', 'starts').exec(function(err) {
    if (err) throw err;
    if (callback) return callback(null);
  });
};

module.exports = {
  onStart: function(client, callback) {
    return client.multi().llen('starts').get('ver').exec(function(err, values) {
      var startsLength, ver;
      if (err) throw err;
      startsLength = values[0];
      ver = values[1] || 0;
      return setStarts(client, startsLength, ver, callback);
    });
  },
  _getStarts: getStarts = function(client, callback) {
    return client.lrange('starts', 0, -1, function(err, starts) {
      var start;
      if (err) throw err;
      if (starts.length === 0) {
        return client.watch('starts', function(err) {
          if (err) throw err;
          return client.llen('starts', function(err, value) {
            if (err) throw err;
            if (value > 0) {
              return client.unwatch('starts', function() {
                return getStarts(client, callback);
              });
            }
            console.error('WARNING: Redis server does not have any record of ' + 'being started by the Racer Redis loader.');
            return setStarts(client, 0, 0, function() {
              return getStarts(client, callback);
            });
          });
        });
      }
      return callback((function() {
        var _i, _len, _results;
        _results = [];
        for (_i = 0, _len = starts.length; _i < _len; _i++) {
          start = starts[_i];
          _results.push(start.split(','));
        }
        return _results;
      })());
    });
  },
  subscribeToStarts: function(subClient, client, callback) {
    if (!subClient.__startsListener) {
      subClient.__startsListener = true;
      subClient.on('message', function(channel, message) {
        if (!(channel === '$redisInfo' && message === 'starts')) return;
        return getStarts(client, callback);
      });
    }
    subClient.subscribe('$redisInfo');
    return getStarts(client, callback);
  },
  _console: console
};
